.. _sec_api:

=========================
PORTING IN PROGRESS: API
=========================

.. todo get rid of this page once we've updating the links within the
    simulate() function's docs and decided how to handle the differences
    between simulate() and sim_ancestry.

.. _sec_api_simulation_model:

****************
Simulation model
****************


.. _sec_api_simulation_models:

*****************
Simulation models
*****************

.. todo:: Remove this section and update any references to the label.


.. _sec_api_simulation_models_change_events:

++++++++++++++++++++++++
Simulation model changes
++++++++++++++++++++++++

.. todo:: Remove this section and update any references to the label.

.. _sec_api_simulate_from:

*********************************************
Initialising simulations from a tree sequence
*********************************************

.. todo:: Remove this section and update any references to the label.


